@@ -180,13 +180,11 @@ def django_instance_field_to_redis_value(
             )
             for django_many_to_many_instance in django_field_value.all()
         ]
-    elif django_field.__class__.__name__.endswith('File'):
+    elif django_field.__class__.__name__.startswith('Image') or django_field.__class__.__name__.startswith('File'):
         try:
             redis_value = django_field_value.path
         except:
             print(django_field.__class__.__name__, django_field_value.__dict__)
-    else:
-        print(django_field, django_field.__class__.__name__)
     return redis_value
 
 
